package com.fastbee.common.core.domain;

import com.fastbee.common.constant.HttpStatus;
import com.fastbee.common.utils.StringUtils;

import java.util.HashMap;

/**
 * 操作消息提醒
 * 
 * @author ruoyi
 */
public class AjaxResultPro extends HashMap<String, Object>
{
    private static final long serialVersionUID = 1L;

    /** 状态码 */
    public static final String CODE_TAG = "code";

    /** 返回内容 */
    public static final String MSG_TAG = "msg";

    /** 数据对象 */
    public static final String DATA_TAG = "data";

    /**
     * 初始化一个新创建的 AjaxResult 对象，使其表示一个空消息。
     */
    public AjaxResultPro()
    {
    }

    /**
     * 初始化一个新创建的 AjaxResult 对象
     *
     * @param code 状态码
     * @param msg 返回内容
     */
    public AjaxResultPro(int code, String msg)
    {
        super.put(CODE_TAG, code);
        super.put(MSG_TAG, msg);
    }

    /**
     * 初始化一个新创建的 AjaxResult 对象
     *
     * @param code 状态码
     * @param msg 返回内容
     * @param data 数据对象
     */
    public AjaxResultPro(int code, String msg, Object data)
    {
        super.put(CODE_TAG, code);
        super.put(MSG_TAG, msg);
        super.put(DATA_TAG, data);
    }


    /**
     * 初始化一个新创建的 AjaxResult 对象
     *
     * @param code 状态码
     * @param msg 返回内容
     * @param data 数据对象
     */
    public AjaxResultPro(int code, String msg, Object data, int total)
    {
        super.put(CODE_TAG, code);
        super.put(MSG_TAG, msg);

            super.put(DATA_TAG, data);
        super.put("total",total);
    }

    /**
     * 返回成功消息
     * 
     * @return 成功消息
     */
    public static AjaxResultPro success()
    {
        return AjaxResultPro.success("操作成功");
    }

    /**
     * 返回成功数据
     * 
     * @return 成功消息
     */
    public static AjaxResultPro success(Object data)
    {
        return AjaxResultPro.success("操作成功", data);
    }




    /**
     * 返回成功数据
     *
     * @return 成功消息
     */
    public static AjaxResultPro success(Object data, int total)
    {
        return new AjaxResultPro(HttpStatus.SUCCESS, "操作成功", data,total);
    }

//    /**
//     * 返回成功消息
//     *
//     * @param msg 返回内容
//     * @return 成功消息
//     */
//    public static AjaxResultPro success(String msg)
//    {
//        return AjaxResultPro.success(msg, null);
//    }

    /**
     * 返回成功消息
     * 
     * @param msg 返回内容
     * @param data 数据对象
     * @return 成功消息
     */
    public static AjaxResultPro success(String msg, Object data)
    {
        return new AjaxResultPro(HttpStatus.SUCCESS, msg, data);
    }


    /**
     * 返回成功消息
     *
     * @param msg 返回内容
     * @param data 数据对象
     * @return 成功消息
     */
    public static AjaxResultPro success(int code,String msg, Object data)
    {
        return new AjaxResultPro(code, msg, data);
    }

    /**
     * 返回警告消息
     *
     * @param msg 返回内容
     * @return 警告消息
     */
    public static AjaxResultPro warn(String msg)
    {
        return AjaxResultPro.warn(msg, null);
    }

    /**
     * 返回警告消息
     *
     * @param msg 返回内容
     * @param data 数据对象
     * @return 警告消息
     */
    public static AjaxResultPro warn(String msg, Object data)
    {
        return new AjaxResultPro(HttpStatus.WARN, msg, data);
    }

    /**
     * 返回错误消息
     * 
     * @return 错误消息
     */
    public static AjaxResultPro error()
    {
        return AjaxResultPro.error("操作失败");
    }

    /**
     * 返回错误消息
     * 
     * @param msg 返回内容
     * @return 错误消息
     */
    public static AjaxResultPro error(String msg)
    {
        return AjaxResultPro.error(msg, null);
    }

    /**
     * 返回错误消息
     * 
     * @param msg 返回内容
     * @param data 数据对象
     * @return 错误消息
     */
    public static AjaxResultPro error(String msg, Object data)
    {
        return new AjaxResultPro(HttpStatus.ERROR, msg, data);
    }

    /**
     * 返回错误消息
     * 
     * @param code 状态码
     * @param msg 返回内容
     * @return 错误消息
     */
    public static AjaxResultPro error(int code, String msg)
    {
        return new AjaxResultPro(code, msg, null);
    }

    /**
     * 方便链式调用
     *
     * @param key 键
     * @param value 值
     * @return 数据对象
     */
    @Override
    public AjaxResultPro put(String key, Object value)
    {
        super.put(key, value);
        return this;
    }
}
