package com.fastbee.common.core.domain.entity;

import java.util.ArrayList;
import java.util.List;
import javax.validation.constraints.Email;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.fastbee.common.core.domain.BaseEntity;

/**
 * 部门表 sys_dept
 *
 * @author ruoyi
 */
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "SysDept", description = "部门表 sys_dept")
@Data
public class SysDept extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 部门ID */
    @ApiModelProperty("部门ID")
    private Long deptId;

    /**
     * 机构系统账号ID
     */
    private Long deptUserId;

    /** 父部门ID */
    @ApiModelProperty("父部门ID")
    private Long parentId;

    /** 祖级列表 */
    @ApiModelProperty("祖级列表")
    private String ancestors;

    /** 部门名称 */
    @ApiModelProperty("部门名称")
    private String deptName;

    /** 显示顺序 */
    @ApiModelProperty("显示顺序")
    private Integer orderNum;

    /** 负责人 */
    @ApiModelProperty("负责人")
    private String leader;

    /** 联系电话 */
    @ApiModelProperty("联系电话")
    private String phone;

    /** 邮箱 */
    @ApiModelProperty("邮箱")
    private String email;

    /** 部门状态:0正常,1停用 */
    @ApiModelProperty("部门状态:0正常,1停用")
    private String status;

    /** 删除标志（0代表存在 2代表删除） */
    @ApiModelProperty("删除标志（0代表存在 2代表删除）")
    private String delFlag;

    /** 行政区域 */
    @ApiModelProperty("行政区域")
    private String administrativeArea;

    /** 行政区域代码 */
    @ApiModelProperty("行政区域代码")
    private String administrativeAreaCode;

    /** 行政区域省代码 */
    @ApiModelProperty("行政区域省代码")
    private String provinceCode;

    /** 行政区域市代码 */
    @ApiModelProperty("行政区域市代码")
    private String cityCode;

    /** 行政区域县代码 */
    @ApiModelProperty("行政区域县代码")
    private String countyCode;

    /** 行政区域镇代码 */
    @ApiModelProperty("行政区域镇代码")
    private String townCode;

    /** 行政区域村代码 */
    @ApiModelProperty("行政区域村代码")
    private String villageCode;

    /** 部门管理的项目id */
    @ApiModelProperty("部门管理的项目id")
    private Long projectId;

    /** 机构的行政级别(3县4镇5村) */
    @ApiModelProperty("机构的行政级别(3县4镇5村)")
    private Integer administrativeLevel;
    //业务字段-----------------------------------------------------------------------------------------------------------

    /** 父部门名称 */
    @ApiModelProperty("父部门名称")
    private String parentName;

    /** 子部门 */
    @ApiModelProperty("子部门")
    private List<SysDept> children = new ArrayList<SysDept>();

    /**
     * 系统账号名称
     */
    private String userName;

    /**
     * 系统账号密码
     */
    private String password;

    /**
     * 确认密码
     */
    private String confirmPassword;

    /**
     * 机构类型
     */
    private Integer deptType;

    /**
     * 是否显示自己
     */
    private Boolean showOwner;

    /**
     * 管理员姓名
     */

    private String deptUserName;


    @NotBlank(message = "部门名称不能为空")
    @Size(min = 0, max = 30, message = "部门名称长度不能超过30个字符")
    public String getDeptName()
    {
        return deptName;
    }

    @NotNull(message = "显示顺序不能为空")
    public Integer getOrderNum()
    {
        return orderNum;
    }

    @Size(min = 0, max = 11, message = "联系电话长度不能超过11个字符")
    public String getPhone()
    {
        return phone;
    }

    @Email(message = "邮箱格式不正确")
    @Size(min = 0, max = 50, message = "邮箱长度不能超过50个字符")
    public String getEmail()
    {
        return email;
    }



}
