package com.fastbee.mq.redischannel.consumer;

import cn.hutool.core.date.DateTime;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.baomidou.mybatisplus.extension.conditions.update.LambdaUpdateChainWrapper;
import com.fastbee.common.constant.FastBeeConstant;
import com.fastbee.common.core.domain.entity.SysUser;
import com.fastbee.common.core.mq.DeviceReportBo;
import com.fastbee.common.utils.DateUtils;
import com.fastbee.iot.domain.DeviceReportInfo;
import com.fastbee.iot.domain.NgCardSwipeRecords;
import com.fastbee.iot.mapper.DeviceReportInfoMapper;
import com.fastbee.iot.mapper.NgCardSwipeRecordsMapper;
import com.fastbee.mq.redischannel.producer.IssueInstructionsProducer;
import com.fastbee.mq.service.impl.DeviceOtherMsgHandler;
import com.fastbee.mqttclient.PubMqttClient;
import com.fastbee.rechargecard.domain.NgUserRechargeRecords;
import com.fastbee.rechargecard.domain.NgWaterPumpUsageRecords;
import com.fastbee.rechargecard.domain.UserIrrigationRecord;
import com.fastbee.rechargecard.domain.UserRechargeCards;
import com.fastbee.rechargecard.mapper.NgUserRechargeRecordsMapper;
import com.fastbee.rechargecard.mapper.NgWaterPumpUsageRecordsMapper;
import com.fastbee.rechargecard.mapper.UserIrrigationRecordMapper;
import com.fastbee.rechargecard.mapper.UserRechargeCardsMapper;
import com.fastbee.system.mapper.SysUserMapper;
import lombok.extern.slf4j.Slf4j;
import org.h2.engine.User;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;
import javax.annotation.Resource;
import java.math.BigDecimal;
import java.nio.charset.StandardCharsets;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.format.DateTimeFormatter;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * @author gsb
 * @date 2023/2/27 14:33
 */
@Slf4j
@Component
public class DeviceOtherMsgConsumer {

    @Resource
    private DeviceOtherMsgHandler otherMsgHandler;

    @Autowired
    private IssueInstructionsProducer issueInstructionsProducer;

    @Autowired
    private DeviceReportInfoMapper deviceReportInfoMapper;

    @Autowired
    private NgWaterPumpUsageRecordsMapper ngWaterPumpUsageRecordsMapper;

    @Autowired
    private NgUserRechargeRecordsMapper ngUserRechargeRecordsMapper;

    @Autowired
    private UserIrrigationRecordMapper userIrrigationRecordMapper;

    @Autowired
    private UserRechargeCardsMapper userRechargeCardsMapper;

    @Autowired
    private NgCardSwipeRecordsMapper ngCardSwipeRecordsMapper;

    @Autowired
    private SysUserMapper sysUserMapper;

    @Autowired
    private StringRedisTemplate stringRedisTemplate;

    @Autowired
    private PubMqttClient pubMqttClient;

    @Async(FastBeeConstant.TASK.DEVICE_OTHER_TASK)
    public void consume(DeviceReportBo bo){
        //处理emq订阅的非 property/post 属性上报的消息 ，因为其他消息量小，放在一起处理
        Long productId;//产品id,设备所属产品
        byte[] data = bo.getData();//数据
        String topic=bo.getTopicName();//主题
        //从主题中解析出产品id
        String[] split = topic.split("/");
        productId= Long.valueOf(split[1]);
        //从主题中解析出设备序列号
        String serialNumber= split[2];//设备序列号
        try {

             System.err.println("主题："+topic+"--产品id:"+productId+"--设备序列号:"+serialNumber);
            //设备上报数据消息---------------------------------------------------------------------------------
            if(topic.endsWith("/info/up")){
                deviceDataReportHandler(productId,serialNumber,JSONUtil.parseObj(new String(data)));
                //更新设备在线状态
                updateDeviceOnlineStatus(productId,serialNumber);//拼成一个唯一的key，只要key存在，则设备在线
                // updateDeviceOnlineStatusDb(serialNumber);
                //保存使用记录
                NgWaterPumpUsageRecords pumpUsageRecords=new NgWaterPumpUsageRecords();
                pumpUsageRecords.setDeviceNumber(serialNumber);
                JSONObject jsonObject = JSONUtil.parseObj(new String(data));
                //报文中data部分
                JSONObject data1 = jsonObject.getJSONObject("data");
                if(jsonObject.getStr("type")!=null){
                    //上报正常数据
                    if("waterEleData".equals(jsonObject.getStr("type"))){

                        //收到开阀时的定时报文
                        if("timeMsg".equals(data1.get("action"))){
                            pumpUsageRecords.setMessageContent(JSONUtil.toJsonStr(jsonObject));
                            LambdaUpdateChainWrapper<DeviceReportInfo> up = new LambdaUpdateChainWrapper<>(deviceReportInfoMapper)
                                    .eq(DeviceReportInfo::getSerialNumber, serialNumber);
                            //获取流量计累计用水量/瞬时流量
                            Float meterSum = data1.getFloat("meterSum");
                            Float meterIns = data1.getFloat("meterIns");

                            //获取瞬时功率/累计电量
                            Float insPower = data1.getFloat("insPower");
                            Float sumEle = data1.getFloat("sumEle");

                            //获取设备当前运行状态
                            Integer valveState = data1.getInt("valveState");

                            //获取地址值/类型
                            Integer flowModel = data1.getInt("meterType");
                            Integer addr = data1.getInt("meterAddr");

                            //获取水单价
                            Float waterFees = data1.getFloat("waterFees");
                            Integer runStatus = null;
                            if(valveState==0){
                                runStatus=2;
                            } else if (valveState==1) {
                                runStatus=1;
                            }
                            if(runStatus!=null){
                                up.set(DeviceReportInfo::getRunStatus,runStatus);
                            }
                            if(flowModel!=null){
                                up.set(DeviceReportInfo::getFlowModel,flowModel);
                            }
                            if(addr!=null){
                                up.set(DeviceReportInfo::getAddr,addr);
                            }
                            if(waterFees!=null){
                                up.set(DeviceReportInfo::getWaterFree,waterFees);
                            }
                            if(meterIns!=null){
                                up.set(DeviceReportInfo::getInsFlow,meterIns);
                            }
                            if(meterSum!=null){
                                up.set(DeviceReportInfo::getSumFlow,meterSum);
                            }
                            //同步数据
                            up.update();
                            //保存历史数据
                            NgWaterPumpUsageRecords historyData = new NgWaterPumpUsageRecords();
                            //瞬时流量
                            historyData.setInsFlow(String.valueOf(meterIns));
                            //累计流量
                            historyData.setSumFlow(String.valueOf(meterSum));
                            //瞬时功率
                            historyData.setInsPower(String.valueOf(insPower));
                            //累计用电量
                            historyData.setSumEle(String.valueOf(sumEle));
                            //实时时间
                            historyData.setRealTime(DateUtils.getNowDate());
                            int i = ngWaterPumpUsageRecordsMapper.insertNgWaterPumpUsageRecords(historyData);
                            if(i<1){
                                log.error("保存灌溉控制器历史数据失败");
                            }
                        }
                        //收到关阀时的平安报文
                        else if("safeMsg".equals(JSONUtil.parseObj(data1).get("action"))){
                            pumpUsageRecords.setMessageContent(JSONUtil.toJsonStr(jsonObject));

                            LambdaUpdateChainWrapper<DeviceReportInfo> up = new LambdaUpdateChainWrapper<>(deviceReportInfoMapper)
                                    .eq(DeviceReportInfo::getSerialNumber, serialNumber);
                            //获取流量计累计用水量/瞬时流量
                            Float meterSum = data1.getFloat("meterSum");
                            Float meterIns = data1.getFloat("meterIns");
                            //获取瞬时功率/累计电量
                            Float insPower = data1.getFloat("insPower");
                            Float sumEle = data1.getFloat("sumEle");
                            //获取设备当前运行状态
                            Integer valveState = data1.getInt("valveState");

                            //获取地址值/类型
                            Integer flowModel = data1.getInt("meterType");
                            Integer addr = data1.getInt("meterAddr");

                            //获取水单价
                            Float waterFees = data1.getFloat("waterFees");
                            Integer runStatus = null;
                            if(valveState==0){
                                runStatus=2;
                            } else if (valveState==1) {
                                runStatus=1;
                            }
                            if(runStatus!=null){
                               up.set(DeviceReportInfo::getRunStatus,runStatus);
                            }
                            if(flowModel!=null){
                                up.set(DeviceReportInfo::getFlowModel,flowModel);
                            }
                            if(addr!=null){
                                 up.set(DeviceReportInfo::getAddr,addr);
                            }
                            if(waterFees!=null){
                                 up.set(DeviceReportInfo::getWaterFree,waterFees);
                            }
                            if(meterIns!=null){
                                 up.set(DeviceReportInfo::getInsFlow,meterIns);
                            }
                            if(meterSum!=null){
                                 up.set(DeviceReportInfo::getSumFlow,meterSum);
                            }
                            //同步数据
                            up.update();
                            //保存历史数据
                            NgWaterPumpUsageRecords historyData = new NgWaterPumpUsageRecords();
                            //瞬时流量
                            historyData.setInsFlow(String.valueOf(meterIns));
                            //累计流量
                            historyData.setSumFlow(String.valueOf(meterSum));
                            //瞬时功率
                            historyData.setInsPower(String.valueOf(insPower));
                            //累计用电量
                            historyData.setSumEle(String.valueOf(sumEle));
                            //实时时间
                            historyData.setRealTime(DateUtils.getNowDate());
                            int i = ngWaterPumpUsageRecordsMapper.insertNgWaterPumpUsageRecords(historyData);
                            if(i<1){
                                log.error("保存灌溉控制器历史数据失败");
                            }

                        }
                        //处理开阀门报文
                        else if("startPump".equals(JSONUtil.parseObj(data1).get("action"))){
                            // int i = ngWaterPumpUsageRecordsMapper.insertNgWaterPumpUsageRecords(pumpUsageRecords);
                            // if(i<1){
                            //     System.err.println("--------------------------保存使用记录失败!---------------------------");
                            // }
                            JSONObject dataJson=jsonObject.getJSONObject("data");
                                log.info("设备{}开阀",serialNumber);
                                //开阀-添加灌溉记录
                                UserIrrigationRecord userIrrigationRecord=new UserIrrigationRecord();
                                userIrrigationRecord.setDeviceNumber(serialNumber);//设备编码

                                String cardNumber= String.valueOf(dataJson.getInt("cardId"));//解析cardId
                                userIrrigationRecord.setCardNumber(cardNumber);//卡号

                                String areaCode=dataJson.getStr("areaCode");
                                userIrrigationRecord.setAreaCode(areaCode);//区域号
                                System.err.println("areaCode"+areaCode);

                                UserRechargeCards cardInfo=userRechargeCardsMapper.selectUserRechargeCardsByCardNumberAndAreaCode(cardNumber,areaCode);
                                //根据卡号查询用户所属机构
                                List<UserRechargeCards> cardList = new LambdaQueryChainWrapper<>(userRechargeCardsMapper)
                                        .select(UserRechargeCards::getUserId,UserRechargeCards::getDeptId,UserRechargeCards::getUserName)
                                    .eq(UserRechargeCards::getCardNumber, cardNumber)
                                        // .ne(UserRechargeCards::getDeptId, null)
                                    .list();
                            // Long deptId= null;//获取deptId
                            if(!cardList.isEmpty()){
                                // if(cardList.get(0).getDeptId()!=null){
                                //   deptId= cardList.get(0).getDeptId();
                                // }
                                //添加一条刷卡记录
                                NgCardSwipeRecords ngCardSwipeRecords=new NgCardSwipeRecords();
                                ngCardSwipeRecords.setCardNumber(cardNumber);//卡号
                                ngCardSwipeRecords.setDeviceNumber(serialNumber);//设备编码
                                ngCardSwipeRecords.setAreaCode(areaCode);//区域号
                                ngCardSwipeRecords.setCardSwipeType(0);//开阀
                                ngCardSwipeRecords.setCardSwipeTime(DateUtils.getNowDate());//刷卡时间
                                if(cardInfo!=null && cardInfo.getUserId()!=null){
                                    ngCardSwipeRecords.setUserId(cardList.get(0).getUserId());//用户id
                                }
                                if(cardInfo!=null && cardInfo.getUserName()!=null){
                                    ngCardSwipeRecords.setUserName(cardList.get(0).getUserName());//用户名称
                                }
                                int flag1=ngCardSwipeRecordsMapper.insertNgCardSwipeRecords(ngCardSwipeRecords);
                                if(flag1<1)
                                {
                                    log.error("设备{}开阀刷卡记录添加失败",serialNumber);
                                }
                            }

                                // userIrrigationRecord.setDeptId(deptId);

                                DateTime currentTime=DateTime.now();//获取当前时间作为开阀时间
                                userIrrigationRecord.setStartTime(currentTime);//开阀时间
                                System.err.println("currentTime"+currentTime);
                                userIrrigationRecord.setLastTime(currentTime);//灌溉最新上报时间

                                BigDecimal openCumFlow=dataJson.getBigDecimal("userSumFlow");//用户开阀时总使用水量
                                userIrrigationRecord.setOpenCumFlow(openCumFlow);//用户开阀时使用水量
                                System.err.println("openCumFlow"+openCumFlow);

                                userIrrigationRecord.setStatus(1);//状态改为灌溉中
                                System.out.println(userIrrigationRecord);
                                userIrrigationRecord.setCreateTime(DateUtils.getNowDate());
                                int flag=userIrrigationRecordMapper.insertUserIrrigationRecord(userIrrigationRecord);//开阀时添加一条灌溉记录
                                if(flag<1)
                                {
                                    log.error("设备{}灌溉记录添加失败",serialNumber);
                                }


                        }
                        //处理关阀门报文
                        else if ("stopPump".equals(JSONUtil.parseObj(data1).get("action"))) {
                            JSONObject dataJson=jsonObject.getJSONObject("data");

                            log.info("设备{}关阀",serialNumber);
                            //关阀-修改灌溉记录，修改结束时间、灌溉用水量（做差 关阀-开阀用户总累计流量。）查卡号最新一条记录
                            String cardNumber=dataJson.getStr("cardId");//解析cardId
                            //根据设备编码和卡号获取当前状态为灌溉中的灌溉记录
                            List<UserIrrigationRecord> irrigationRecordList = new LambdaQueryChainWrapper<>(userIrrigationRecordMapper)
                                    .select(UserIrrigationRecord::getId, UserIrrigationRecord::getStartTime,UserIrrigationRecord::getOpenCumFlow)
                                    .eq(UserIrrigationRecord::getCardNumber, cardNumber)
                                    .eq(UserIrrigationRecord::getStatus,1)
                                    .orderByDesc(UserIrrigationRecord::getStartTime)
                                    .list();
                            if(irrigationRecordList.isEmpty())
                            {
                                log.error("设备{}灌溉记录不存在",serialNumber);
                            }else{
                                //根据卡号查询用户所属机构
                                List<UserRechargeCards> cardList = new LambdaQueryChainWrapper<>(userRechargeCardsMapper)
                                        .select(UserRechargeCards::getUserId,UserRechargeCards::getDeptId,UserRechargeCards::getUserName)
                                        .eq(UserRechargeCards::getCardNumber, cardNumber)
                                        // .ne(UserRechargeCards::getDeptId, null)
                                        .list();
                                UserIrrigationRecord userIrrigationRecord=new UserIrrigationRecord();
                                userIrrigationRecord.setId(irrigationRecordList.get(0).getId());

                                log.info("查询到{}设备的灌溉记录{}",serialNumber,userIrrigationRecord);
                                DateTime currentTime=DateTime.now();//获取当前时间作为关阀时间
                                userIrrigationRecord.setEndTime(currentTime);//关阀时间
                                userIrrigationRecord.setLastTime(currentTime);//灌溉最新上报时间

                                BigDecimal closeCumFlow=dataJson.getBigDecimal("userSumFlow");//用户关阀时总用水量
                                // System.err.println("用户开阀时总用水量:"+irrigationRecordList.get(0).getOpenCumFlow());
                                // System.err.println("用户关阀时总用水量:"+closeCumFlow);
                                userIrrigationRecord.setCloseCumFlow(closeCumFlow);

                                BigDecimal currentFlow=closeCumFlow.subtract(irrigationRecordList.get(0).getOpenCumFlow());//计算结果为当前用水量
                                //当前用水量
                                log.info("设备{}本次灌溉用户当前用水量{}",serialNumber,currentFlow);
                                userIrrigationRecord.setCurFlow(currentFlow);

                                BigDecimal userBalance=dataJson.getBigDecimal("userBalance");//用户余额
                                System.err.println("用户余额:"+userBalance);
                                userIrrigationRecord.setBalance(userBalance);

                                userIrrigationRecord.setStatus(2);//灌溉状态更改为结束灌溉


                                log.info("封装关阀数据{}",userIrrigationRecord);
                                int flag=userIrrigationRecordMapper.updateById(userIrrigationRecord);//关阀时修改一条灌溉记录
                                if(flag<1)
                                {
                                    log.error("设备{}灌溉记录修改失败",serialNumber);
                                }

                                //添加一条刷卡记录
                                String areaCode=dataJson.getStr("areaCode");
                                // UserRechargeCards cardInfo=userRechargeCardsMapper.selectUserRechargeCardsByCardNumberAndAreaCode(cardNumber,areaCode);//查询卡号+区域号信息

                                NgCardSwipeRecords ngCardSwipeRecords=new NgCardSwipeRecords();
                                ngCardSwipeRecords.setCardNumber(cardNumber);//卡号
                                ngCardSwipeRecords.setDeviceNumber(serialNumber);//设备编码
                                ngCardSwipeRecords.setAreaCode(areaCode);//区域号
                                ngCardSwipeRecords.setCardSwipeType(1);//关阀
                                ngCardSwipeRecords.setCardSwipeTime(DateUtils.getNowDate());//刷卡时间

                                // ngCardSwipeRecords.setUserId(cardList.get(0).getUserId());//用户id

                                // ngCardSwipeRecords.setUserName(cardList.get(0).getUserName());//用户名称

                               int flag1=ngCardSwipeRecordsMapper.insertNgCardSwipeRecords(ngCardSwipeRecords);
                                if(flag1<1)
                                {
                                    log.error("设备{}关阀刷卡记录添加失败",serialNumber);
                                }

                            }
                        }
                    }

                    //收到心跳报文
                    else if("heartBeat".equals(jsonObject.getStr("type"))){
                            //需要回应
                            //构建回复消息-----------------------------------------------------------------------------
                            Map<String,Object> reportMsg=new HashMap<>();
                            reportMsg.put("code",100);
                            reportMsg.put("pakSn",jsonObject.getStr("pakSn"));
                            issueInstructionsProducer.receiveDataReportResponse(productId.toString(),serialNumber,JSONUtil.toJsonStr(reportMsg));
                        }

                }
                //如果是设备刷卡上报的查询报文
                if(data1.getStr("action")!=null&& "askMsg".equals(data1.getStr("action"))){
                    cardReportHandler(productId,serialNumber,jsonObject);
                }

            }

            else if (topic.endsWith("/info/reply")) {
                platformDataReportAckHandler(new String(data));
                updateDeviceOnlineStatus( productId,serialNumber);

            }
            else if (topic.endsWith("/cmd/down")) {
                platformCmdHandler(new String(data));


            } else if (topic.endsWith("/cmd/reply")) {
                //收到充值结果指令
                JSONObject jsonObject = JSONUtil.parseObj(new String(data));
                if("devCmdAck".equals(jsonObject.getStr("type"))){
                    JSONObject data1 = jsonObject.getJSONObject("data");
                    Long orderNum = data1.getLong("orderNum");
                    //修改订单状态为已充值
                    boolean update = new LambdaUpdateChainWrapper<>(ngUserRechargeRecordsMapper)
                                .set(NgUserRechargeRecords::getStatus, 3)
                                .eq(NgUserRechargeRecords::getId, orderNum)
                                .update();
                    if(!update){
                         log.error("修改订单号为：{}的订单状态为已充值失败",orderNum);
                    }

                }
                deviceCmdAckHandler(new String(data));
                updateDeviceOnlineStatus( productId,serialNumber);
                // updateDeviceOnlineStatusDb(serialNumber);
            }
            otherMsgHandler.messageHandler(bo);
        }catch (Exception e){
            e.printStackTrace();
            log.error("=>主题:{}设备消息:{}处理出错:{}",topic,new String(data), e.getMessage());
        }
    }


    /**
     * 更新设备在线状态
     */
    private void updateDeviceOnlineStatus(Long productId,String serialNumber){

        try {
            //缓存里面更新设备在线状态
            if(Boolean.TRUE.equals(stringRedisTemplate.hasKey("neixiang_device_online_status:" + productId + ":" + serialNumber))){
                //重新设置过期时间
                stringRedisTemplate.expire("neixiang_device_online_status:"+productId+":"+serialNumber,360, TimeUnit.SECONDS);
                return;
            }
            stringRedisTemplate.opsForValue().set("neixiang_device_online_status:"+productId+":"+serialNumber,"1",360, TimeUnit.SECONDS);

            //数据库里面更新设备在线状态
            boolean update = new LambdaUpdateChainWrapper<>(deviceReportInfoMapper)
                    .set(DeviceReportInfo::getOnLine, 1)
                    .eq(DeviceReportInfo::getSerialNumber, serialNumber)
                    .update();
            if(!update){
                log.error("=>数据库更新灌溉控制器设备在线状态失败！");
            }
        }catch (Exception e){
            log.error("=>更新缓存设备在线状态出错",e);
        }
    }
    /**
     * 数据库更新设备在线状态
     */
    private void updateDeviceOnlineStatusDb(String serialNumber){
        try {
            boolean update = new LambdaUpdateChainWrapper<>(deviceReportInfoMapper)
                    .set(DeviceReportInfo::getOnLine, 1)
                    .eq(DeviceReportInfo::getSerialNumber, serialNumber)
                    .update();
            if(!update){
                throw new RuntimeException("=>数据库更新设备在线状态失败");
            }
        }catch (Exception e){
            log.error("=>更新数据库设备在线状态出错",e);
        }
    }



    /**
     * 处理设备数据上报 info/up主题消息
     * @param dataObj 消息
     */
    private void deviceDataReportHandler(Long productId,String serialNumber,JSONObject dataObj){
        //消息data部分
        JSONObject data = dataObj.getJSONObject("data");


    }
    /**
     * 处理平台接收到数据上报的回应  info/reply 主题消息
     */
    private void platformDataReportAckHandler(String data){
        // System.err.println("mqtt回应收到设备上报数据："+ data);
        //处理

    }
    /**
     * 处理平台收到给设备下发的指令 cmd/down 主题消息
     */
    private void platformCmdHandler(String data){
        System.err.println("--------------------------------------------------------------mqtt-broker收到给设备下发命令："+ data);
//        JSONObject obj = JSONUtil.parseObj(data);

    }
    /**
     * 处理平台收到设备收到指令回应 cmd/reply 主题消息
     */
    private void deviceCmdAckHandler(String data){
        System.err.println("----------------------------------------------------------------------平台收到设备执行完指令的结果："+ data);
    }

    /**
     * 处理刷卡上报查询报文
     */
    private void cardReportHandler(Long productId,String serialNumber,JSONObject dataObj){
        System.err.println("收到查询报文");
        JSONObject data = dataObj.getJSONObject("data");
        //解析消息
        String cardId=data.getStr("cardId");//卡号
        System.err.println("卡号："+cardId);
        String areaCode=data.getStr("areaCode");//区域码
        System.err.println("区域码："+areaCode);
        //先回应代表平台收到了来自设备的查询报文
        Map<String,Object> reply=new HashMap<>();
        reply.put("pakSn",dataObj.getInt("pakSn"));
        System.err.println("包号" + dataObj.getInt("pakSn"));
        //默认没有充值的订单
        reply.put("code",400);
        Map<String,Object> dataValue=new HashMap<>();

        reply.put("msg","");

        //查询是否待充值的订单
        List<NgUserRechargeRecords> orderList = new LambdaQueryChainWrapper<>(ngUserRechargeRecordsMapper)
                .select(NgUserRechargeRecords::getId, NgUserRechargeRecords::getStatus,NgUserRechargeRecords::getAmount)
                .eq(NgUserRechargeRecords::getCardNumber,cardId)
                .eq(NgUserRechargeRecords::getStatus,1)//待下发状态的订单
                .list();
        //如果有待充值的订单则需要下发充值信息，如果有多条需要下发的充值订单，需要合并充值金额为一条，且订单号取最近的一条
        if(!orderList.isEmpty()){
            System.err.println("amount:"+orderList.get(0).getAmount().doubleValue());
            //合并订单充值金额
            Double investBalance= 0.00;
            for(int i=0;i<=orderList.size()-1;i++){
                //累加金额
                investBalance=investBalance+orderList.get(i).getAmount().doubleValue();
            }
            //取最新的订单号作为合并后的订单
            dataValue.put("orderNum",orderList.get(orderList.size()-1).getId());//订单号
            reply.put("code",410);
            dataValue.put("cardNum",Integer.parseInt(cardId));//卡号
            dataValue.put("areaCode",Integer.parseInt(areaCode));//区域码
            dataValue.put("investBalance",investBalance.doubleValue()*100);//充值金额
            // dataValue.put("investWater",rechargecardUser.getWater()*100);//充值水量
            reply.put("data",dataValue);
            pubMqttClient.publish(1,true,"hzlink/"+productId+"/"+serialNumber+"/info/reply", JSONUtil.toJsonStr(reply));
            return;
        }
        reply.put("data",dataValue);
        pubMqttClient.publish(1,true,"hzlink/"+productId+"/"+serialNumber+"/info/reply", JSONUtil.toJsonStr(reply));
    }

    public static void main(String[] args) {
        System.err.println((LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"))));
        DeviceReportBo bo=new DeviceReportBo();
        bo.setTopicName("hzlink/147/1200028/info/up");
        System.err.println("111");

        String jsonStr = "{"
                + "  \"data\": {"
                + "    \"valveState\": 0,"
                + "    \"userBalance\": 9995102,"
                + "    \"sumFlow\": 640000,"
                + "    \"userSumEle\": 0,"
                + "    \"cardSn\": 1841852732,"
                + "    \"cardType\": 12,"
                + "    \"sumEle\": 0,"
                + "    \"doorStatus\": 100,"
                + "    \"meterIns\": 6100,"
                + "    \"meterStatus\": 1,"
                + "    \"userSumFlow\": 640000,"
                + "    \"cardId\": 402,"
                + "    \"action\": \"startPump\","
                + "    \"meterSum\": 6400,"
                + "    \"pumpState\": 0,"
                + "    \"mcuSn\": 2147483647,"
                + "    \"areaCode\": 6460,"
                + "    \"workState\": 0"
                + "  },"
                + "  \"type\": \"waterEleData\","
                + "  \"pakSn\": 9"
                + "}";


        // 将 JSON 字符串转换为 byte[] 数组
        byte[] jsonBytes = jsonStr.getBytes(StandardCharsets.UTF_8);
        bo.setData(jsonBytes);

        DeviceOtherMsgConsumer deviceOtherMsgConsumer=new DeviceOtherMsgConsumer();
        deviceOtherMsgConsumer.consume(bo);
        System.err.println("end");


    }
}
