package com.fastbee.data.controller.userRecharge;

import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.fastbee.rechargecard.domain.dto.NgWaterPumpUsageRecordsChartsDto;
import com.fastbee.rechargecard.domain.dto.NgWaterPumpUsageRecordsDto;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fastbee.common.annotation.Log;
import com.fastbee.common.core.controller.BaseController;
import com.fastbee.common.core.domain.AjaxResult;
import com.fastbee.common.enums.BusinessType;
import com.fastbee.rechargecard.domain.NgWaterPumpUsageRecords;
import com.fastbee.rechargecard.service.INgWaterPumpUsageRecordsService;
import com.fastbee.common.utils.poi.ExcelUtil;
import com.fastbee.common.core.page.TableDataInfo;

/**
 * 水泵设备使用记录Controller
 *
 * @author kerwincui
 * @date 2024-12-19
 */
@RestController
@RequestMapping("/waterpump/records")
@Api(tags = "水泵设备使用记录")
public class NgWaterPumpUsageRecordsController extends BaseController
{
    @Autowired
    private INgWaterPumpUsageRecordsService ngWaterPumpUsageRecordsService;

    /**
     * 灌溉控制器瞬时流量的图表
     */
//    @PreAuthorize("@ss.hasPermi('rechargecard:records:list')")
    @GetMapping("/charts/insFlow")
    @ApiOperation("灌溉控制器瞬时流量的图表")
    public AjaxResult insFlowCharts(NgWaterPumpUsageRecordsChartsDto ngWaterPumpUsageRecordsChartsDto)
    {
        return success(ngWaterPumpUsageRecordsService.selectNgWaterPumpUsageRecordsInsFlowCharts(ngWaterPumpUsageRecordsChartsDto.getDeviceNumber(),ngWaterPumpUsageRecordsChartsDto.getStartTime(),ngWaterPumpUsageRecordsChartsDto.getEndTime()));
    }

    /**
    * 查询水泵设备使用记录列表
    */
//    @PreAuthorize("@ss.hasPermi('rechargecard:records:list')")
    @GetMapping("/list")
    @ApiOperation("查询水泵设备使用记录列表")
    public TableDataInfo list(NgWaterPumpUsageRecordsDto ngWaterPumpUsageRecords)
    {
        startPage();
        List<NgWaterPumpUsageRecords> list = ngWaterPumpUsageRecordsService.selectNgWaterPumpUsageRecordsListByTime(ngWaterPumpUsageRecords);
        return getDataTable(list);
    }

    /**
     * 导出水泵设备使用记录列表
     */
    @ApiOperation("导出水泵设备使用记录列表")
    //@PreAuthorize("@ss.hasPermi('rechargecard:records:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, NgWaterPumpUsageRecordsDto ngWaterPumpUsageRecords)
    {
        List<NgWaterPumpUsageRecords> list = ngWaterPumpUsageRecordsService.selectNgWaterPumpUsageRecordsListByTime(ngWaterPumpUsageRecords);
        ExcelUtil<NgWaterPumpUsageRecords> util = new ExcelUtil<NgWaterPumpUsageRecords>(NgWaterPumpUsageRecords.class);
        util.exportExcel(response, list, "水泵设备使用记录数据");
    }

    /**
     * 获取水泵设备使用记录详细信息
     */
    // @PreAuthorize("@ss.hasPermi('rechargecard:records:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取水泵设备使用记录详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(ngWaterPumpUsageRecordsService.selectNgWaterPumpUsageRecordsById(id));
    }

    /**
     * 新增水泵设备使用记录
     */
    // @PreAuthorize("@ss.hasPermi('rechargecard:records:add')")
    @PostMapping
    @ApiOperation("新增水泵设备使用记录")
    public AjaxResult add(@RequestBody NgWaterPumpUsageRecords ngWaterPumpUsageRecords)
    {
        return toAjax(ngWaterPumpUsageRecordsService.insertNgWaterPumpUsageRecords(ngWaterPumpUsageRecords));
    }

    /**
     * 修改水泵设备使用记录
     */
    // @PreAuthorize("@ss.hasPermi('rechargecard:records:edit')")
    @PutMapping
    @ApiOperation("修改水泵设备使用记录")
    public AjaxResult edit(@RequestBody NgWaterPumpUsageRecords ngWaterPumpUsageRecords)
    {
        return toAjax(ngWaterPumpUsageRecordsService.updateNgWaterPumpUsageRecords(ngWaterPumpUsageRecords));
    }

    /**
     * 删除水泵设备使用记录
     */
    // @PreAuthorize("@ss.hasPermi('rechargecard:records:remove')")
    @DeleteMapping("/{ids}")
    @ApiOperation("删除水泵设备使用记录")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(ngWaterPumpUsageRecordsService.deleteNgWaterPumpUsageRecordsByIds(ids));
    }
}
