package com.fastbee.deviceData.mapper;


import java.util.List;
import com.fastbee.deviceData.domain.DeviceManufacturers;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Select;

/**
 * 设备厂家信息Mapper接口
 *
 * @author kerwincui
 * @date 2024-12-21
 */
@Mapper
public interface DeviceManufacturersMapper
{
    /**
     * 查询设备厂家信息
     *
     * @param id 设备厂家信息主键
     * @return 设备厂家信息
     */
    public DeviceManufacturers selectDeviceManufacturersById(Long id);

    /**
     * 查询设备厂家信息列表
     *
     * @param deviceManufacturers 设备厂家信息
     * @return 设备厂家信息集合
     */
    public List<DeviceManufacturers> selectDeviceManufacturersList(DeviceManufacturers deviceManufacturers);
    /**
     * 根据type查询设备厂家信息列表
     *
     * @param manufacturerType type值
     * @return 设备厂家信息
     */
    @Select("SELECT * FROM iot_device_manufacturers WHERE manufacturer_type = #{manufacturerType}")
    public List<DeviceManufacturers> selectDeviceManufacturersListType(String manufacturerType);

    /**
     * 新增设备厂家信息
     *
     * @param deviceManufacturers 设备厂家信息
     * @return 结果
     */
    public int insertDeviceManufacturers(DeviceManufacturers deviceManufacturers);

    /**
     * 修改设备厂家信息
     *
     * @param deviceManufacturers 设备厂家信息
     * @return 结果
     */
    public int updateDeviceManufacturers(DeviceManufacturers deviceManufacturers);

    /**
     * 删除设备厂家信息
     *
     * @param id 设备厂家信息主键
     * @return 结果
     */
    public int deleteDeviceManufacturersById(Long id);

    /**
     * 批量删除设备厂家信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDeviceManufacturersByIds(Long[] ids);
}
