package com.fastbee.ggroup.domain;

import java.math.BigDecimal;
import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.fastbee.common.annotation.Excel;
import com.fastbee.common.core.domain.BaseEntity;

/**
 * 水闸基本信息对象 g_site_sluice_info
 *
 * @author kerwincui
 * @date 2024-10-31
 */
@ApiModel(value = "GSiteSluiceInfo",description = "水闸基本信息 g_site_sluice_info")
@Data
@EqualsAndHashCode(callSuper = true)
public class GSiteSluiceInfo extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long id;

    /** 工程名称 */
    @Excel(name = "工程名称")
    @ApiModelProperty("工程名称")
    private String projectName;

    /** 工程编码 */
    @Excel(name = "工程编码")
    @ApiModelProperty("工程编码")
    private String projectCode;

    /** 地理坐标经度 */
    @Excel(name = "地理坐标经度")
    @ApiModelProperty("地理坐标经度")
    private BigDecimal geographicalCoordinatesLongitude;

    /** 地理坐标维度 */
    @Excel(name = "地理坐标维度")
    @ApiModelProperty("地理坐标维度")
    private BigDecimal geographicalCoordinatesLatitude;

    /** 所在河流 */
    @Excel(name = "所在河流")
    @ApiModelProperty("所在河流")
    private String riverName;

    /** 所在灌区 */
    @Excel(name = "所在灌区")
    @ApiModelProperty("所在灌区")
    private String agriculturalIrrigationArea;

    /** 工程建设情况 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "工程建设情况", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty("工程建设情况")
    private String constructionDate;

    /** 是否为枢纽工程 */
    @Excel(name = "是否为枢纽工程")
    @ApiModelProperty("是否为枢纽工程")
    private Integer isHubProject;

    /** 是否为闸站工程 */
    @Excel(name = "是否为闸站工程")
    @ApiModelProperty("是否为闸站工程")
    private Integer isSluiceStationProject;

    /** 是否为套闸工程 */
    @Excel(name = "是否为套闸工程")
    @ApiModelProperty("是否为套闸工程")
    private Integer isNestedSluiceProject;

    /** 工程等级 */
    @Excel(name = "工程等级")
    @ApiModelProperty("工程等级")
    private Long projectGrade;

    /** 主要建筑物等级 */
    @Excel(name = "主要建筑物等级")
    @ApiModelProperty("主要建筑物等级")
    private Long mainBuildingGrade;

    /** 闸孔数量 */
    @Excel(name = "闸孔数量")
    @ApiModelProperty("闸孔数量")
    private Long waterSluiceInfoGatesNumber;

    /** 闸孔总净宽 */
    @Excel(name = "闸孔总净宽")
    @ApiModelProperty("闸孔总净宽")
    private BigDecimal waterSluiceInfoGatesWide;

    /**  工程位置 */
    @Excel(name = " 工程位置")
    @ApiModelProperty(" 工程位置")
    private String projectLocation;

    /** 设计洪水标准 */
    @Excel(name = "设计洪水标准")
    @ApiModelProperty("设计洪水标准")
    private Long designStandard;

    /** 校核洪水标准 */
    @Excel(name = "校核洪水标准")
    @ApiModelProperty("校核洪水标准")
    private Long checkCriteria;

    /** 单位名称 */
    @Excel(name = "单位名称")
    @ApiModelProperty("单位名称")
    private String organizationName;

    /** 权属 */
    @Excel(name = "权属")
    @ApiModelProperty("权属")
    private String ownership;

    /** 负责人 */
    @Excel(name = "负责人")
    @ApiModelProperty("负责人")
    private String responsiblePerson;

    /** 职位 */
    @Excel(name = "职位")
    @ApiModelProperty("职位")
    private String position;

    /** 电话 */
    @Excel(name = "电话")
    @ApiModelProperty("电话")
    private String phoneNumber;

    /** 防汛管理单位负责人 */
    @Excel(name = "防汛管理单位负责人")
    @ApiModelProperty("防汛管理单位负责人")
    private String manageResponsiblePerson;

    /** 防汛管理单位职位 */
    @Excel(name = "防汛管理单位职位")
    @ApiModelProperty("防汛管理单位职位")
    private String managePhonePosts;

    /** 防汛管理单位手机号 */
    @Excel(name = "防汛管理单位手机号")
    @ApiModelProperty("防汛管理单位手机号")
    private String managePhoneNumber;

    /** 防汛行政单位负责人 */
    @Excel(name = "防汛行政单位负责人")
    @ApiModelProperty("防汛行政单位负责人")
    private String administrativeResponsiblePerson;

    /** 防汛行政单位电话 */
    @Excel(name = "防汛行政单位电话")
    @ApiModelProperty("防汛行政单位电话")
    private String administrativePhoneNumber;

    /** 防汛技术单位负责人 */
    @Excel(name = "防汛技术单位负责人")
    @ApiModelProperty("防汛技术单位负责人")
    private String technologyResponsiblePerson;

    /** 防汛技术单位电话 */
    @Excel(name = "防汛技术单位电话")
    @ApiModelProperty("防汛技术单位电话")
    private String technologyPhoneNumber;

    /** 防汛巡查单位负责人 */
    @Excel(name = "防汛巡查单位负责人")
    @ApiModelProperty("防汛巡查单位负责人")
    private String inspectionResponsiblePerson;

    /** 防汛巡查单位电话 */
    @Excel(name = "防汛巡查单位电话")
    @ApiModelProperty("防汛巡查单位电话")
    private String inspectionPhoneNumber;

    /** 是否完成划界 */
    @Excel(name = "是否完成划界")
    @ApiModelProperty("是否完成划界")
    private Integer isBoundaryDelineationCompleted;

    /** 是否完成确权 */
    @Excel(name = "是否完成确权")
    @ApiModelProperty("是否完成确权")
    private Integer isPropertyRightsConfirmationCompleted;

    /** 防汛物资 */
    @Excel(name = "防汛物资")
    @ApiModelProperty("防汛物资")
    private String floodControlMaterials;

    /** 删除标志（0代表存在，2代表删除） */
    private Integer delFlag;

    /** 所属站点id */
    @Excel(name = "所属站点id")
    @ApiModelProperty("所属站点id")
    private Long siteId;

}
