package com.fastbee.iot.service;

import java.util.Date;
import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fastbee.iot.domain.NgFlowDeviceData;
import com.fastbee.iot.domain.dto.NgFlowDeviceDataDto;

/**
 * 流量计设备数据Service接口
 * 
 * @author kerwincui
 * @date 2024-12-30
 */
public interface INgFlowDeviceDataService  extends IService<NgFlowDeviceData>
{
    /**
     * 流量计瞬时流量和累计流量图表
     * @param deviceNumber
     * @param startTime
     * @param endTime
     * @return
     */
    public Map<String,Object> selectNgFlowDeviceDataFlowCharts(String deviceNumber, Date startTime, Date endTime);

    /**
     * 查询流量计设备数据列表
     *
     * @param ngFlowDeviceData 流量计设备数据
     * @return 流量计设备数据集合
     */
    public List<NgFlowDeviceData> selectNgFlowDeviceDataListByTime(NgFlowDeviceDataDto ngFlowDeviceData);

    /**
     * 查询流量计设备数据
     * 
     * @param id 流量计设备数据主键
     * @return 流量计设备数据
     */
    public NgFlowDeviceData selectNgFlowDeviceDataById(Long id);

    /**
     * 查询流量计设备数据列表
     * 
     * @param ngFlowDeviceData 流量计设备数据
     * @return 流量计设备数据集合
     */
    public List<NgFlowDeviceData> selectNgFlowDeviceDataList(NgFlowDeviceData ngFlowDeviceData);

    /**
     * 新增流量计设备数据
     * 
     * @param ngFlowDeviceData 流量计设备数据
     * @return 结果
     */
    public int insertNgFlowDeviceData(NgFlowDeviceData ngFlowDeviceData);

    /**
     * 修改流量计设备数据
     * 
     * @param ngFlowDeviceData 流量计设备数据
     * @return 结果
     */
    public int updateNgFlowDeviceData(NgFlowDeviceData ngFlowDeviceData);

    /**
     * 批量删除流量计设备数据
     * 
     * @param ids 需要删除的流量计设备数据主键集合
     * @return 结果
     */
    public int deleteNgFlowDeviceDataByIds(Long[] ids);

    /**
     * 删除流量计设备数据信息
     * 
     * @param id 流量计设备数据主键
     * @return 结果
     */
    public int deleteNgFlowDeviceDataById(Long id);
}
