package com.fastbee.rechargecard.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fastbee.rechargecard.domain.UserIrrigationRecord;
import com.fastbee.rechargecard.domain.dto.UserIrrigationRecordListDto;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Select;

/**
 * 灌溉记录Mapper接口
 *
 * @author kerwincui
 * @date 2024-12-18
 */
@Mapper
public interface UserIrrigationRecordMapper extends BaseMapper<UserIrrigationRecord>
{
    /**
     * 根据时间段获取灌溉记录列表
     * @param userIrrigationRecordListDto
     * @return
     */
    public List<UserIrrigationRecord> selectUserIrrigationRecordListByTime(UserIrrigationRecordListDto userIrrigationRecordListDto);
    /**
     * 根据卡号和设备编码获取最新的灌溉中的灌溉记录
     * @param cardNumber
     * @param deviceNumber
     * @return
     */
    @Select("select * from user_irrigation_record where card_number=#{cardNumber} AND device_number=#{deviceNumber} AND status=1 order by create_time desc ")
    public List<UserIrrigationRecord> selectUserIrrigationRecordListBycardNumberAndDeviceNumber(String cardNumber,String deviceNumber);
    /**
     * 查询单用户灌溉记录列表
     *
     * @param
     * @return 灌溉记录集合
     */
    public List<UserIrrigationRecord> selectUserIrrigationRecordListBycardNumber(String cardNumber);


    /**
     * 查询单用户灌溉记录列表
     *
     * @param
     * @return 灌溉记录集合
     */
    public List<UserIrrigationRecord> selectUserIrrigationRecordShowListBycardNumber(UserIrrigationRecord userIrrigationRecord);

    /**
     * 查询灌溉控制器灌溉记录列表
     *
     * @param deviceNumber
     * @return 灌溉记录集合
     */
    public List<UserIrrigationRecord> selectUserIrrigationRecordListByDeviceNumber(String deviceNumber);

    /**
     * 查询灌溉记录
     *
     * @param id 灌溉记录主键
     * @return 灌溉记录
     */
    public UserIrrigationRecord selectUserIrrigationRecordById(Long id);

    /**
     * 查询灌溉记录列表
     *
     * @param userIrrigationRecord 灌溉记录
     * @return 灌溉记录集合
     */
    public List<UserIrrigationRecord> selectUserIrrigationRecordList(UserIrrigationRecord userIrrigationRecord);

    /**
     * 新增灌溉记录
     *
     * @param userIrrigationRecord 灌溉记录
     * @return 结果
     */
    public int insertUserIrrigationRecord(UserIrrigationRecord userIrrigationRecord);

    /**
     * 修改灌溉记录
     *
     * @param userIrrigationRecord 灌溉记录
     * @return 结果
     */
    public int updateUserIrrigationRecord(UserIrrigationRecord userIrrigationRecord);

    /**
     * 删除灌溉记录
     *
     * @param id 灌溉记录主键
     * @return 结果
     */
    public int deleteUserIrrigationRecordById(Long id);

    /**
     * 批量删除灌溉记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteUserIrrigationRecordByIds(Long[] ids);
}
