package com.fastbee.rechargecard.service.impl;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.SimpleDateFormat;
import java.time.format.DateTimeFormatter;
import java.util.*;

import cn.hutool.core.date.DateUtil;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.fastbee.common.utils.DateUtils;
import com.fastbee.common.utils.json.JsonStrUtil;
import com.fastbee.common.utils.json.JsonUtils;
import com.fastbee.iot.mapper.DeviceMapper;
import com.fastbee.rechargecard.domain.NgUserRechargeRecords;
import com.fastbee.rechargecard.domain.dto.NgWaterPumpUsageRecordsDto;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fastbee.rechargecard.mapper.NgWaterPumpUsageRecordsMapper;
import com.fastbee.rechargecard.domain.NgWaterPumpUsageRecords;
import com.fastbee.rechargecard.service.INgWaterPumpUsageRecordsService;

/**
 * 水泵设备使用记录Service业务层处理
 * 
 * @author kerwincui
 * @date 2024-12-19
 */
@Service
public class NgWaterPumpUsageRecordsServiceImpl implements INgWaterPumpUsageRecordsService 
{
    @Autowired
    private NgWaterPumpUsageRecordsMapper ngWaterPumpUsageRecordsMapper;

    @Autowired
    private DeviceMapper deviceMapper;

    @Override
    public Map<String, Object> selectNgWaterPumpUsageRecordsInsFlowCharts(String deviceNumber,Date startTime,Date endTime) {
        QueryWrapper<NgWaterPumpUsageRecords> queryWrapper=new QueryWrapper<>();
        Map<String,Object> resultMap=new HashMap<>();
        List<BigDecimal> insList=new ArrayList<>();
        List<BigDecimal> sumList=new ArrayList<>();
        List<String> timeList=new ArrayList<>();

        Date start = DateUtil.beginOfDay(DateUtil.date());// 获取今日零点时间
        Date now = DateUtil.date();// 获取当前时间
        // 获取当前整点时刻的时间
        Date end = DateUtil.beginOfHour(now);//用当前整点时刻时间作为结束时间
        if (startTime != null && endTime != null) {
            //如果有时间筛选，按照时间筛选为起止时间
            start=startTime;
            end=endTime;
        }

        queryWrapper.between("real_time", start, end);
        queryWrapper.eq("device_number",deviceNumber);
        List<NgWaterPumpUsageRecords>  list=ngWaterPumpUsageRecordsMapper.selectList(queryWrapper);//获取根据时间和设备编码筛选后的数据
        if(list.size()==0)
        {
            return null;
        }

        while(start.compareTo(end) <=0 )//start<=end
        {
            //整点时间数据=前半个小时到后半个小时的平均数据，即12点数据=11:30到12：30的平均值
            Date tempStart=DateUtil.offsetMinute(start,-30);//前半个小时时间
            Date tempEnd=DateUtil.offsetMinute(start,30);//后半个小时时间
            if(tempEnd.after(now))
            {
                tempEnd=now;//用来处理当前是12：10但需要获取12点数据的情况
            }
            BigDecimal insData=new BigDecimal("0");//瞬时流量总和
            BigDecimal sumData=new BigDecimal("0");//累计流量总和
            int num=0;
            for(int i=0;i<list.size();i++)
            {
                NgWaterPumpUsageRecords temp=list.get(i);
                //如果时间符合条件
                if(temp.getRealTime().compareTo(tempStart)>=0 && temp.getRealTime().compareTo(tempEnd)<=0)
                {
                    BigDecimal insFlow=new BigDecimal(temp.getInsFlow());//瞬时流量
                    insData=insData.add(insFlow);
                    BigDecimal sumFlow=new BigDecimal(temp.getSumFlow());//累计流量
                    sumData=sumData.add(sumFlow);
                    num++;
                }
            }
            BigDecimal insResult=new BigDecimal("0");
            BigDecimal sumResult=new BigDecimal("0");
            if(num>0)
            {
                insResult = insData.divide(new BigDecimal(String.valueOf(num)), 2, RoundingMode.HALF_UP);//计算瞬时流量平均值
                sumResult=sumData.divide(new BigDecimal(String.valueOf(num)),2,RoundingMode.HALF_UP);//计算累计流量平均值
            }
            SimpleDateFormat sdf = new SimpleDateFormat("HH:mm");//格式化为时：分
            String formattedDate = sdf.format(start);
            timeList.add(formattedDate);
            insList.add(insResult);
            sumList.add(sumResult);

            start=DateUtil.offsetHour(start,1);//start添加一个小时
        }
        resultMap.put("time",timeList);
        resultMap.put("insFlow",insList);
        resultMap.put("sumFlow",sumList);

        return resultMap;
    }

    /**
     * 可根据时间段筛选灌溉控制器历史数据
     * @param ngWaterPumpUsageRecords 水泵设备使用记录
     * @return
     */
    @Override
    public List<NgWaterPumpUsageRecords> selectNgWaterPumpUsageRecordsListByTime(NgWaterPumpUsageRecordsDto ngWaterPumpUsageRecords) {
        if(ngWaterPumpUsageRecords.getStartTime() != null && ngWaterPumpUsageRecords.getEndTime() != null)
        {
            //设置结束时间加一天
            Date searchEndTime = ngWaterPumpUsageRecords.getEndTime();
            // 使用 Calendar 给日期加一天
            Calendar calendar = Calendar.getInstance();
            calendar.setTime(searchEndTime);
            calendar.add(Calendar.DATE, 1); // 给日期加一天
            // 将计算后的日期设置回 userIrrigationRecord 对象
            ngWaterPumpUsageRecords.setEndTime(calendar.getTime());
        }

        return ngWaterPumpUsageRecordsMapper.selectNgWaterPumpUsageRecordsListByTime(ngWaterPumpUsageRecords);
    }

    /**
     * 查询水泵设备使用记录
     * 
     * @param id 水泵设备使用记录主键
     * @return 水泵设备使用记录
     */
    @Override
    public NgWaterPumpUsageRecords selectNgWaterPumpUsageRecordsById(Long id)
    {
        return ngWaterPumpUsageRecordsMapper.selectNgWaterPumpUsageRecordsById(id);
    }

    /**
     * 查询水泵设备最细实时数据
     * @param deviceNumber 水泵设备编码
     * @return 水泵设备使用记录
     */
    @Override
    public HashMap<String,Object> selectNgWaterPumpUsageDeviceNumber(String deviceNumber)
    {

        NgWaterPumpUsageRecords result = ngWaterPumpUsageRecordsMapper.selectNgWaterPumpUsageDeviceNumber(deviceNumber);
        NgWaterPumpUsageRecords ngWaterPumpUsageRecords = new NgWaterPumpUsageRecords();
        System.err.println(result);
        HashMap<String,Object> map = new HashMap<String,Object>();
        if (result != null) {
            String message= result.getMessageContent();
            JSONObject jsonObject1 = JSONUtil.parseObj(message);
            String jsonStr = jsonObject1.getStr("data");
            JSONObject jsonObject2 = JSONUtil.parseObj(jsonStr);
            if (jsonObject2.getStr("meterIns")!=null){
                map.put("meterIns",jsonObject2.getStr("meterIns"));
            }else {
                map.put("meterIns",0);
            }
            if (jsonObject2.getStr("meterSum")!=null){
                map.put("meterSum",jsonObject2.getStr("meterSum"));
            }else {
                map.put("meterSum",0);
            }
            System.err.println(jsonStr);
            return map;
        } else {
            map.put("meterIns",0);
            map.put("meterSum",0);
            return map;
        }
    }

    /**
     * 查询水泵设备使用记录列表
     * 
     * @param ngWaterPumpUsageRecords 水泵设备使用记录
     * @return 水泵设备使用记录
     */
    @Override
    public List<NgWaterPumpUsageRecords> selectNgWaterPumpUsageRecordsList(NgWaterPumpUsageRecords ngWaterPumpUsageRecords)
    {
        return ngWaterPumpUsageRecordsMapper.selectNgWaterPumpUsageRecordsList(ngWaterPumpUsageRecords);
    }

    /**
     * 新增水泵设备使用记录
     * 
     * @param ngWaterPumpUsageRecords 水泵设备使用记录
     * @return 结果
     */
    @Override
    public int insertNgWaterPumpUsageRecords(NgWaterPumpUsageRecords ngWaterPumpUsageRecords)
    {
        return ngWaterPumpUsageRecordsMapper.insertNgWaterPumpUsageRecords(ngWaterPumpUsageRecords);
    }

    /**
     * 修改水泵设备使用记录
     * 
     * @param ngWaterPumpUsageRecords 水泵设备使用记录
     * @return 结果
     */
    @Override
    public int updateNgWaterPumpUsageRecords(NgWaterPumpUsageRecords ngWaterPumpUsageRecords)
    {
        return ngWaterPumpUsageRecordsMapper.updateNgWaterPumpUsageRecords(ngWaterPumpUsageRecords);
    }

    /**
     * 批量删除水泵设备使用记录
     * 
     * @param ids 需要删除的水泵设备使用记录主键
     * @return 结果
     */
    @Override
    public int deleteNgWaterPumpUsageRecordsByIds(Long[] ids)
    {
        return ngWaterPumpUsageRecordsMapper.deleteNgWaterPumpUsageRecordsByIds(ids);
    }

    /**
     * 删除水泵设备使用记录信息
     * 
     * @param id 水泵设备使用记录主键
     * @return 结果
     */
    @Override
    public int deleteNgWaterPumpUsageRecordsById(Long id)
    {
        return ngWaterPumpUsageRecordsMapper.deleteNgWaterPumpUsageRecordsById(id);
    }
}
