package com.fastbee.rechargecard.service.impl;

import java.math.BigDecimal;
import java.util.*;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.fastbee.common.utils.DateUtils;
import com.fastbee.iot.mapper.DeviceMapper;
import com.fastbee.rechargecard.domain.NgIrrigationControllers;
import com.fastbee.rechargecard.domain.NgUserRechargeRecords;
import com.fastbee.rechargecard.domain.UserConsumptionDetails;
import com.fastbee.rechargecard.domain.dto.UserIrrigationRecordDto;
import com.fastbee.rechargecard.domain.dto.UserIrrigationRecordListDto;
import com.fastbee.rechargecard.mapper.NgIrrigationControllersMapper;
import com.fastbee.system.mapper.SysUserMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fastbee.rechargecard.mapper.UserIrrigationRecordMapper;
import com.fastbee.rechargecard.domain.UserIrrigationRecord;
import com.fastbee.rechargecard.service.IUserIrrigationRecordService;

/**
 * 灌溉记录Service业务层处理
 *
 * @author kerwincui
 * @date 2024-12-18
 */
@Service
public class UserIrrigationRecordServiceImpl implements IUserIrrigationRecordService
{
    @Autowired
    private UserIrrigationRecordMapper userIrrigationRecordMapper;
    @Autowired
    private SysUserMapper sysUserMapper;
    @Autowired
    private NgIrrigationControllersMapper ngIrrigationControllersMapper;


    /**
     * 统计灌溉记录中的总用水量和总用水户
     * @param userIrrigationRecordListDto
     * @return
     */
    @Override
    public Map<String, Object> getTotal(UserIrrigationRecordListDto userIrrigationRecordListDto) {
        if(userIrrigationRecordListDto.getSearchStartTime()!=null && userIrrigationRecordListDto.getSearchEndTime()!=null)
        {
            //设置结束时间加一天
            Date endTime = userIrrigationRecordListDto.getSearchEndTime();
            // 使用 Calendar 给日期加一天
            Calendar calendar = Calendar.getInstance();
            calendar.setTime(endTime);
            calendar.add(Calendar.DATE, 1); // 给日期加一天
            // 将计算后的日期设置回 userIrrigationRecord 对象
            userIrrigationRecordListDto.setSearchEndTime(calendar.getTime());
        }
        // 统计cur_flow字段的总和
        QueryWrapper<UserIrrigationRecord> sumQueryWrapper = new QueryWrapper<>();
        if(userIrrigationRecordListDto.getDeptId()!=null)
        {
            sumQueryWrapper.eq("dept_id",userIrrigationRecordListDto.getDeptId());
        }
        sumQueryWrapper.select("SUM(cur_flow) as sumFlow");
        if (userIrrigationRecordListDto.getSearchStartTime() != null && userIrrigationRecordListDto.getSearchEndTime() != null) {
            sumQueryWrapper.between("end_time", userIrrigationRecordListDto.getSearchStartTime(), userIrrigationRecordListDto.getSearchEndTime());
        }
        Map<String, Object> sumResult = userIrrigationRecordMapper.selectMaps(sumQueryWrapper).get(0);
        if(sumResult==null)
        {
            return null;
        }
        //double totalAmount = ((Number) sumResult.get("sumAmount")).doubleValue();
        BigDecimal totalFlow= (BigDecimal) sumResult.get("sumFlow");

        // 对cardNumber字段进行去重并统计总和
        QueryWrapper<UserIrrigationRecord> distinctQueryWrapper = new QueryWrapper<>();
        if(userIrrigationRecordListDto.getDeptId()!=null)
        {
            distinctQueryWrapper.eq("dept_id",userIrrigationRecordListDto.getDeptId());
        }
        distinctQueryWrapper.select("COUNT(DISTINCT card_number) as distinctCount");
        if (userIrrigationRecordListDto.getSearchStartTime() != null && userIrrigationRecordListDto.getSearchEndTime() != null) {
            distinctQueryWrapper.between("end_time", userIrrigationRecordListDto.getSearchStartTime(), userIrrigationRecordListDto.getSearchEndTime());
        }
        Map<String, Object> distinctResult = userIrrigationRecordMapper.selectMaps(distinctQueryWrapper).get(0);
        if(distinctResult==null)
        {
            return null;
        }
        long distinctCardNumberCount = ((Number) distinctResult.get("distinctCount")).longValue();

        Map<String,Object> result=new HashMap<>();
        result.put("totalFlow",totalFlow);//总用水量
        result.put("totalUserNumber",distinctCardNumberCount);//总用水户

        return result;
    }

    @Override
    public List<UserIrrigationRecordListDto> selectUserIrrigationRecordListByTime(UserIrrigationRecordListDto userIrrigationRecord) {
        List<UserIrrigationRecord> list = userIrrigationRecordMapper.selectUserIrrigationRecordListByTime(userIrrigationRecord);
        List<UserIrrigationRecordListDto> result=new ArrayList<>();
        for(int i=0;i<list.size();i++)
        {
            UserIrrigationRecordListDto temp=new UserIrrigationRecordListDto();
            temp.setId(list.get(i).getId());

            if(list.get(i).getUserId()!=null)
            {
                temp.setUserId(list.get(i).getUserId());
                temp.setUserName(sysUserMapper.selectUserById(list.get(i).getUserId()).getUserName()==null ? "" :sysUserMapper.selectUserById(list.get(i).getUserId()).getUserName());
            }

            temp.setDeviceNumber(list.get(i).getDeviceNumber());
            temp.setProjectId(list.get(i).getProjectId());
            temp.setDeptId(list.get(i).getDeptId());
            temp.setCardNumber(list.get(i).getCardNumber());
            temp.setAreaCode(list.get(i).getAreaCode());
            temp.setCurFlow(list.get(i).getCurFlow());
            temp.setCurEle(list.get(i).getCurEle());
            temp.setBalance(list.get(i).getBalance());
            temp.setStartTime(list.get(i).getStartTime());
            temp.setEndTime(list.get(i).getEndTime());
            temp.setDuration(list.get(i).getDuration());
            temp.setUnit(list.get(i).getUnit());
            temp.setLastTime(list.get(i).getLastTime());
            temp.setStatus(list.get(i).getStatus());
            temp.setRemarks(list.get(i).getRemarks());
            temp.setOpenCumFlow(list.get(i).getOpenCumFlow());
            temp.setCloseCumFlow(list.get(i).getCloseCumFlow());

            result.add(temp);

        }
        return result;
    }

    @Override
    public List<UserIrrigationRecordDto> selectUserIrrigationRecordShowListByCardNumber(UserIrrigationRecord userIrrigationRecord) {
        List<UserIrrigationRecordDto> result=new ArrayList<>();
        List<UserIrrigationRecord> list=userIrrigationRecordMapper.selectUserIrrigationRecordShowListBycardNumber(userIrrigationRecord);
        for(int i=0;i<list.size();i++)
        {
            UserIrrigationRecordDto temp=new UserIrrigationRecordDto();
            temp.id=list.get(i).getId();
            if(list.get(i).getUserId()!=null)
            {
                temp.userName= sysUserMapper.selectUserById(list.get(i).getUserId()).getUserName()==null ? "" :sysUserMapper.selectUserById(list.get(i).getUserId()).getUserName();

            }
            if(list.get(i).getDeviceNumber()!=null)
            {
                temp.deviceName=ngIrrigationControllersMapper.selectNgIrrigationControllersBySerialNumber(list.get(i).getDeviceNumber()).getControllerName() == null ? "":ngIrrigationControllersMapper.selectNgIrrigationControllersBySerialNumber(list.get(i).getDeviceNumber()).getControllerName();

            }
           temp.cardNumber=list.get(i).getCardNumber() == null ? "" : list.get(i).getCardNumber();
            temp.flow=list.get(i).getCurFlow()==null ? BigDecimal.valueOf(0) :list.get(i).getCurFlow();
            temp.startTime=list.get(i).getStartTime()==null ? null : list.get(i).getStartTime();
            temp.endTime=list.get(i).getEndTime()==null ? null :list.get(0).getEndTime();
            result.add(temp);
        }

        return result;
    }

    @Override
    public List<UserIrrigationRecord> selectUserIrrigationRecordShowListByDeviceNumber(String deviceNumber) {
        List<UserIrrigationRecord> list=userIrrigationRecordMapper.selectUserIrrigationRecordListByDeviceNumber(deviceNumber);
        return list;
    }

    @Override
    public List<UserIrrigationRecordDto> selectUserIrrigationRecordShowList(UserIrrigationRecord userIrrigationRecord) {
        List<UserIrrigationRecordDto> result=new ArrayList<>();
        List<UserIrrigationRecord> list=userIrrigationRecordMapper.selectUserIrrigationRecordList(userIrrigationRecord);
        for(int i=0;i<list.size();i++)
        {
            UserIrrigationRecordDto temp=new UserIrrigationRecordDto();
            temp.id=list.get(i).getId();
            if(list.get(i).getUserId()!=null)
            {
                temp.userName= sysUserMapper.selectUserById(list.get(i).getUserId()).getUserName()==null ? "" :sysUserMapper.selectUserById(list.get(i).getUserId()).getUserName();

            }
            if(list.get(i).getDeviceNumber()!=null)
            {
                temp.deviceName=ngIrrigationControllersMapper.selectNgIrrigationControllersBySerialNumber(list.get(i).getDeviceNumber()).getControllerName() == null ? "":ngIrrigationControllersMapper.selectNgIrrigationControllersBySerialNumber(list.get(i).getDeviceNumber()).getControllerName();

            }
            temp.deviceNumber=list.get(i).getDeviceNumber();
            temp.cardNumber=list.get(i).getCardNumber() == null ? "" : list.get(i).getCardNumber();
            temp.flow=list.get(i).getCurFlow()==null ? BigDecimal.valueOf(0) :list.get(i).getCurFlow();
            temp.startTime=list.get(i).getStartTime()==null ? null : list.get(i).getStartTime();
            temp.endTime=list.get(i).getEndTime()==null ? null :list.get(0).getEndTime();
            result.add(temp);
        }

        return result;
    }

    /**
     * 获取用户灌溉记录列表
     * @param cardNumber 卡号
     * @return
     */
    @Override
    public List<UserIrrigationRecordDto> selectUserIrrigationRecordListBycardNumber(String cardNumber)
    {
        //return userIrrigationRecordMapper.selectUserIrrigationRecordListBycardNumber(cardNumber);
        List<UserIrrigationRecordDto> result=new ArrayList<>();
        List<UserIrrigationRecord> list=userIrrigationRecordMapper.selectUserIrrigationRecordListBycardNumber(cardNumber);
        for(int i=0;i<list.size();i++)
        {
            UserIrrigationRecordDto temp=new UserIrrigationRecordDto();
            temp.id=list.get(i).getId();
            if(list.get(i).getUserId()!=null)
            {
                temp.userName= sysUserMapper.selectUserById(list.get(i).getUserId()).getUserName();
            }
            if(list.get(i).getDeviceNumber()!=null)
            {
                temp.deviceName=ngIrrigationControllersMapper.selectNgIrrigationControllersBySerialNumber(list.get(i).getDeviceNumber()).getControllerName();

            }
            temp.cardNumber=list.get(i).getCardNumber();
            temp.flow=list.get(i).getCurFlow();
            temp.startTime=list.get(i).getStartTime();
            temp.endTime=list.get(i).getEndTime();
            result.add(temp);
        }

        return result;
    }

    /**
     * 获取用户灌溉记录展示数据列表
     * @param cardNumber 卡号
     * @return
     */
    /*@Override
    public List<UserIrrigationRecordDto> selectUserIrrigationRecordListShowBycardNumber(String cardNumber)
    {
        List<UserIrrigationRecordDto> result=new ArrayList<>();
        List<UserIrrigationRecord> list=userIrrigationRecordMapper.selectUserIrrigationRecordListBycardNumber(cardNumber);
        for(int i=0;i<list.size();i++)
        {
            UserIrrigationRecordDto temp=new UserIrrigationRecordDto();
            temp.id=list.get(i).getId();
            temp.userName= sysUserMapper.selectUserById(list.get(i).getUserId()).getUserName();
            temp.deviceName=deviceMapper.selectDeviceBySerialNumber(list.get(i).getDeviceNumber()).getDeviceName();
            temp.cardNumber=list.get(i).getCardNumber();
            temp.flow=list.get(i).getCurFlow();
            temp.startTime=list.get(i).getStartTime();
            temp.endTime=list.get(i).getEndTime();
            result.add(temp);
        }

        return result;
    }*/

    /**
     * 查询灌溉记录
     *
     * @param id 灌溉记录主键
     * @return 灌溉记录
     */
    @Override
    public UserIrrigationRecord selectUserIrrigationRecordById(Long id)
    {
        return userIrrigationRecordMapper.selectUserIrrigationRecordById(id);
    }

    /**
     * 查询灌溉记录列表
     *
     * @param userIrrigationRecord 灌溉记录
     * @return 灌溉记录
     */
    @Override
    public List<UserIrrigationRecord> selectUserIrrigationRecordList(UserIrrigationRecord userIrrigationRecord)
    {
        return userIrrigationRecordMapper.selectUserIrrigationRecordList(userIrrigationRecord);
    }

    /**
     * 新增灌溉记录
     *
     * @param userIrrigationRecord 灌溉记录
     * @return 结果
     */
    @Override
    public int insertUserIrrigationRecord(UserIrrigationRecord userIrrigationRecord)
    {
        userIrrigationRecord.setCreateTime(DateUtils.getNowDate());
        return userIrrigationRecordMapper.insertUserIrrigationRecord(userIrrigationRecord);
    }

    /**
     * 修改灌溉记录
     *
     * @param userIrrigationRecord 灌溉记录
     * @return 结果
     */
    @Override
    public int updateUserIrrigationRecord(UserIrrigationRecord userIrrigationRecord)
    {
        userIrrigationRecord.setUpdateTime(DateUtils.getNowDate());
        return userIrrigationRecordMapper.updateUserIrrigationRecord(userIrrigationRecord);
    }

    /**
     * 批量删除灌溉记录
     *
     * @param ids 需要删除的灌溉记录主键
     * @return 结果
     */
    @Override
    public int deleteUserIrrigationRecordByIds(Long[] ids)
    {
        return userIrrigationRecordMapper.deleteUserIrrigationRecordByIds(ids);
    }

    /**
     * 删除灌溉记录信息
     *
     * @param id 灌溉记录主键
     * @return 结果
     */
    @Override
    public int deleteUserIrrigationRecordById(Long id)
    {
        return userIrrigationRecordMapper.deleteUserIrrigationRecordById(id);
    }
}
